# Development

Thank you for your interest in installer! ✨

installer is a volunteer maintained open source project, and we welcome
contributions of all forms. This section of installer's documentation serves as
a resource to help you to contribute to the project.

```{toctree}
:hidden:

workflow
design
```

<!-- prettier-ignore-start -->
[Code of Conduct]
: Applies within all community spaces. If you are not familiar with our Code of Conduct, take a minute to read it before starting with your first contribution.

[Workflow](./workflow)
: Describes how to work on this project. Start here if you're a new contributor.

[Design and Scope](./design)
: Describes what this project is for, and how that informs the design decisions made.
<!-- prettier-ignore-end -->

[code of conduct]: https://github.com/pypa/.github/blob/main/CODE_OF_CONDUCT.md
